<?php
/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\Storelocator\Controller\PickUpInStore;

use \Magento\Framework\Exception\NotFoundException;

/**
 * Responsible for loading page content.
 *
 * This is a basic controller that only loads the corresponding layout file. It may duplicate other such
 * controllers, and thus it is considered tech debt. This code duplication will be resolved in future releases.
 */
class Rmareceived extends \Magento\Framework\App\Action\Action
{
    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $resultPageFactory;

    /** @var \FiloBlu\Storelocator\Helper\Data */
    protected $helper;

    protected $_rma;

    protected $_coreRegistry;

    protected $_order;

    public function __construct(
        \Magento\Framework\App\Action\Context $context ,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory ,
        \FiloBlu\Storelocator\Helper\Data $helper ,
        \Magento\Rma\Model\Rma $rma ,
        \Magento\Framework\Registry $registry
    )
    {
        $this->resultPageFactory = $resultPageFactory;
        $this->helper = $helper;
        $this->_rma = $rma;
        $this->_coreRegistry = $registry;
        parent::__construct($context);
    }

    /**
     *
     * @return \Magento\Framework\View\Result\Page
     */
    public function execute()
    {
        $params = $this->getRequest()->getParams();

        if (!$this->helper->getConfig('carriers/pickupinstore/active') || !isset($params["rma_id"]) || !$params["rma_id"] || !isset($params["hash"]) || !$params["hash"]) {
            return $this->_forward('noRoute');
        }

        $this->_rma->load($params["rma_id"]);
        $this->_order = $this->_rma->getOrder();

        if ($this->_order->getId() && $this->_rma->getReturnToStoreHash() == $params["hash"] && (int)$this->_rma->getReturnToStoreId() > 0) {
            $this->_coreRegistry->register('pickupinstore_rma_received' , $this->_rma);
            $resultPage = $this->resultPageFactory->create();

            $title = __("PickUp In Store - Confirmation of acceptance of the package for return ");

            if (!$this->helper->getConfig(\FiloBlu\Storelocator\Helper\Data::USE_STANDARD_PICKRMA_MAIL_FLOW) && $this->_rma->getStatus() == 'pending') {
                $title = __("PickUp In Store - Confirmation of authorization of the package for return ");
            }

            $resultPage->getConfig()->getTitle()->set($title . $this->_rma->getData("increment_id"));

            return $resultPage;
        } else {
            return $this->_forward('noRoute');
        }
    }
}
